# KarLib

This is an open source python library of useful utilities that simplify everyday coding task.


## Table of Contents

- [Installation](#-installation)
- [Usage/Examples](#-usageexamples)
- [Contributing](#-contributing)
- [License](#-license)


## Installation

Install this project using pypi package manager.
```bash
$ pip install karlib
```

## Usage/Examples

See wiki for all usage examples.


## Contributing

Contributing towards this repo is open heartedly welcomed. Please make sure to add comments wherever needed to provide some clarity. Any type of code which damages other's properties will not be tolerated.

1. Fork the repository.
2. Create a new branch: `git checkout -b feature-name`.
3. Make your changes.
4. Push your branch: `git push origin feature-name`.
5. Create a pull request.


## License

[![MIT License](https://img.shields.io/badge/License-MIT-green.svg)](https://choosealicense.com/licenses/mit/)

This is an open source project which is under MIT License. For more information please read the license file.
